@@ -261,6 +261,7 @@ class ExtractSuperClasses(Visitor):
     self._superclasses = {}
 
   def _Key(self, node):
+    # This method should be implemented by subclasses.
     return node
 
   def VisitTypeDeclUnit(self, module):
@@ -273,8 +274,6 @@ class ExtractSuperClasses(Visitor):
       parent = self._Key(p)
       if parent is not None:
         parents.append(parent)
-    # TODO(kramm): This uses the entire class node as a key, instead of just
-    # its id.
     self._superclasses[self._Key(cls)] = parents
 
 
@@ -470,9 +469,8 @@ class PrintVisitor(Visitor):
   def VisitClass(self, node):
     """Visit a class, producing a multi-line, properly indented string."""
     parents = node.parents
-    # If classobj is the only parent, then this is an old-style class, don't
-    # list any parents.
-    if parents == ("classobj",):
+    # If object is the only parent, we don't need to list any parents.
+    if parents == ("object",):
       parents = ()
     if node.metaclass is not None:
       parents += ("metaclass=" + node.metaclass,)
